@@ -10,7 +10,7 @@
 #  ┃ of the [Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0). ┃
 #  ┗━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┛
 
-__version__ = "4.0.1"
+__version__ = "4.1.0"
 __all__ = [
     "_jupyter_labextension_paths",
     "Server",
@@ -21,6 +21,7 @@ __all__ = [
     "ProxySession",
     "AsyncClient",
     "AsyncServer",
+    "VirtualServer",
     "num_cpus",
     "set_num_cpus",
     "system_info",
@@ -351,6 +352,7 @@ from .perspective import (
     Server,
     AsyncServer,
     AsyncClient,
+    VirtualServer,
     # NOTE: these are classes without constructors,
     # so we import them just for type hinting
     Table,  # noqa: F401
