@@ -26,6 +26,69 @@ __version__ = re.sub(".dev[0-9]+", "", importlib.metadata.version("perspective-p
 
 __all__ = ["PerspectiveWidget"]
 
+__doc__ = """
+`PerspectiveWidget` is a JupyterLab widget that implements the same API as
+`<perspective-viewer>`, allowing for fast, intuitive
+transformations/visualizations of various data formats within JupyterLab.
+
+`PerspectiveWidget` is compatible with Jupyterlab 3 and Jupyter Notebook 6 via a
+[prebuilt extension](https://jupyterlab.readthedocs.io/en/stable/extension/extension_dev.html#prebuilt-extensions).
+To use it, simply install `perspective-python` and the extensions should be
+available.
+
+`perspective-python`'s JupyterLab extension also provides convenient builtin
+viewers for `csv`, `json`, or `arrow` files. Simply right-click on a file with
+this extension and choose the appropriate `Perpective` option from the context
+menu.
+
+## `PerspectiveWidget`
+
+Building on top of the API provided by `perspective.Table`, the
+`PerspectiveWidget` is a JupyterLab plugin that offers the entire functionality
+of Perspective within the Jupyter environment. It supports the same API
+semantics of `<perspective-viewer>`, along with the additional data types
+supported by `perspective.Table`. `PerspectiveWidget` takes keyword arguments
+for the managed `View`:
+
+```python
+from perspective.widget import PerspectiveWidget
+w = perspective.PerspectiveWidget(
+    data,
+    plugin="X Bar",
+    aggregates={"datetime": "any"},
+    sort=[["date", "desc"]]
+)
+```
+
+### Creating a widget
+
+A widget is created through the `PerspectiveWidget` constructor, which takes as
+its first, required parameter a `perspective.Table`, a dataset, a schema, or
+`None`, which serves as a special value that tells the Widget to defer loading
+any data until later. In maintaining consistency with the Javascript API,
+Widgets cannot be created with empty dictionaries or lists—`None` should be used
+if the intention is to await data for loading later on. A widget can be
+constructed from a dataset:
+
+```python
+from perspective.widget import PerspectiveWidget
+PerspectiveWidget(data, group_by=["date"])
+```
+
+.. or a schema:
+
+```python
+PerspectiveWidget({"a": int, "b": str})
+```
+
+.. or an instance of a `perspective.Table`:
+
+```python
+table = perspective.table(data)
+PerspectiveWidget(table)
+```
+"""
+
 
 class PerspectiveWidget(DOMWidget, PerspectiveViewer):
     """`PerspectiveWidget` allows for Perspective to be used as a Jupyter
@@ -62,10 +125,10 @@ class PerspectiveWidget(DOMWidget, PerspectiveViewer):
 
     # Required by ipywidgets for proper registration of the backend
     _model_name = Unicode("PerspectiveModel").tag(sync=True)
-    _model_module = Unicode("@finos/perspective-jupyterlab").tag(sync=True)
+    _model_module = Unicode("@perspective-dev/jupyterlab").tag(sync=True)
     _model_module_version = Unicode("~{}".format(__version__)).tag(sync=True)
     _view_name = Unicode("PerspectiveView").tag(sync=True)
-    _view_module = Unicode("@finos/perspective-jupyterlab").tag(sync=True)
+    _view_module = Unicode("@perspective-dev/jupyterlab").tag(sync=True)
     _view_module_version = Unicode("~{}".format(__version__)).tag(sync=True)
 
     def __init__(
@@ -253,8 +316,8 @@ class PerspectiveWidget(DOMWidget, PerspectiveViewer):
                 path = f"cdn/{module}.js"
 
             # perspective developer affordance: works with your local `pnpm run start blocks`
-            # return f"http://localhost:8080/node_modules/@finos/{module}/dist/{path}"
-            return f"https://cdn.jsdelivr.net/npm/@finos/{module}@{__version__}/dist/{path}"
+            # return f"http://localhost:8080/node_modules/@perspective-dev/{module}/dist/{path}"
+            return f"https://cdn.jsdelivr.net/npm/@perspective-dev/{module}@{__version__}/dist/{path}"
 
         return super(DOMWidget, self)._repr_mimebundle_(**kwargs) | {
             "text/html": template.substitute(
