@@ -627,7 +627,7 @@ impl AsyncTable {
 #[pyclass]
 #[derive(Clone)]
 pub struct AsyncView {
-    view: Arc<View>,
+    pub(crate) view: Arc<View>,
     _client: AsyncClient,
 }
 
@@ -645,7 +645,6 @@ impl AsyncView {
             .transpose()?
             .unwrap_or_default();
 
-        tracing::error!("Window {:?}", window);
         self.view.column_paths(window).await.into_pyerr()
     }
 
